****************************************************************************************************************************
***REPLICATION DO-FILE FOR KLEINBERG, ROBINSON, FRENCH 2012 JOP "TRADE CONCENTRATION AND INTERSTATE CONFLICT****************
***These commands produce the findings presented in all tables and figures**************************************************
***This file also contains commands for robustness checks requested by anonymous reviewers**********************************
***For a do-file detailing the creation of the main independent variable, contact Katja Kleinberg kkleinbe@binghamton.edu***
****************************************************************************************************************************

set mem 700m
set more off

use "(...)KleinbergRobinsonFrench2012JOP.dta"

*****Results for Table 1*****
* Replication of Russett/Oneal 2005 with limited time period
* Column 1: Any MID Standard model
btscs mzmid1 year dyadid, gen(pcy) 
gen pcy2=pcy*pcy
gen pcy3=pcy*pcy*pcy
logit mzmid1 lnmindev low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

* Column 2: Any MID Full model
logit mzmid1 lnmindev lower_conc low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
drop  pcy pcy2 pcy3

* Column 3: Fatal MIDs Standard Model
btscs midfatal year dyadid, gen(pcy) 
gen pcy2=pcy*pcy
gen pcy3=pcy*pcy*pcy
logit midfatal lnmindev low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

* Column 4: Fatal MIDs Full Model
logit midfatal lnmindev lower_conc low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
drop  pcy pcy2 pcy3

*****Postestimation Analysis based on Column 4, Table 1***************************************
btscs midfatal year dyadid, gen(pcy) 
gen pcy2=pcy*pcy
gen pcy3=pcy*pcy*pcy
logit midfatal lower_conc low_share lnmindev low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

*****Figure 2*****
*change in predicted probability of fatal MID for meaningful range of lower_conc with CI - contiguous states
* Predicted probabilities for (reduced) range of values for trade concentration
prgen lower_conc, from(.1) to(.8) generate(prmid) x(allies=0 majpow=0 contig_dummy=1) rest(mean) n(12) ci
label variable prmidx "Concentration of Extradyadic Trade"
label variable  prmidp1lb "95% lower limit"
label variable  prmidp1ub "95% upper limit"
label variable prmidp1 "Predicted Probability"
graph twoway (connected  prmidp1 prmidx, clcolor(black) clpat(solid) clwidth(medthick) msymbol(none) mcolor(none)) (connected  prmidp1ub prmidx, msymbol(none) mcolor(none) clcolor(black) clpat(dash) clwidth(thin)) (connected  prmidp1lb prmidx, msymbol(none) mcolor(none) clcolor(black) clpat(dash) clwidth(thin)), ytitle("Probability of Fatal Dispute") ylabel(, grid glwidth(medium) glpattern(solid)) xlabel(0.1 (0.1) 0.8)
drop prmidx prmidp0 prmidp1 prmidp0lb prmidp1lb prmidp0ub prmidp1ub 

drop pcy pcy2 pcy3

*****Figure 3*****
*change in predicted probability of fatal MID for different levels of dyadic trade dependence (figure)
btscs midfatal year dyadid, gen(pcy) 
gen pcy2=pcy*pcy
gen pcy3=pcy*pcy*pcy
logit midfatal lower_conc low_share lnmindev low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
sum low_share if e(sample)==1 & low_share!=0, detail

*@ low_share==0
prgen lower_conc, from (.1) to (.8) generate (p0) x(low_share=0 allies=0 majpow=0 contig_dummy=1) rest(mean) n(12)
label variable p0p1 "No Dyadic Trade"

*@ low_share=mean 0.0027136
prgen lower_conc, from (.1) to (.8) generate (pmean) x(low_share=0.0027136 allies=0 majpow=0 contig_dummy=1) rest(mean) n(12)
label variable pmeanp1 "Mean Trade Dependence"

*@ low_share=mean+2std dev  0.0232942
prgen lower_conc, from (.1) to (.8) generate (p2sd) x(low_share=0.0232942 allies=0 majpow=0 contig_dummy=1) rest(mean) n(12)
label variable p2sdp1 "High Trade Dependence"

graph twoway (connected p0p1 p0x, clcolor(black) clpat(solid) clwidth(medthin) msymbol(O)) (connected pmeanp1 pmeanx, clcolor(black) clpat(solid) clwidth(medthin) msymbol(X)) (connected p2sdp1 p2sdx, clcolor(black) clpat(solid) clwidth(medthin) msymbol(T)), ytitle("Probability of Fatal Dispute") xtitle("Concentration of Extradyadic Trade") xlabel(0 (0.1) 0.8)
drop pcy pcy2 pcy3


*****Table 2*****
btscs midfatal year dyadid, gen(pcy) 
gen pcy2=pcy*pcy
gen pcy3=pcy*pcy*pcy
logit midfatal lower_conc low_share lnmindev low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

estat sum
predict fatalmidprob if e(sample)==1
sum fatalmidprob
prvalue, x(contig_dummy=1 allies=0 majpow=0) rest(mean) brief
listcoef, percent help
prchange, x(contig_dummy=1 allies=0 majpow=0) fromto help
sum lower_conc if e(sample), detail
*non-contiguous states
prvalue, x(contig_dummy=0 allies=0 majpow=0) rest(mean) brief
*allies
prvalue, x(contig_dummy=1 allies=1 majpow=0) rest(mean) brief
*major power
prvalue, x(contig_dummy=1 allies=0 majpow=1) rest(mean) brief

*******Robustness checks*************************************
btscs midfatal year dyadid, gen(pcy) 
gen pcy2=pcy*pcy
gen pcy3=pcy*pcy*pcy

*Table 1*
logit midfatal lnmindev low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

*Politically relevant dyads*
logit midfatal lnmindev low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3 if politrel==1, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3 if politrel==1, robust cluster(dyadid) nolog

*Alternative measure of political relations: S-score (Signorino&Ritter)*
logit midfatal lnmindev low_share low_dem high_dem contig_dummy s_wt_glo lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev low_share low_dem high_dem contig_dummy s_wt_glo lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

*Alternative measure of trade dependence*
logit midfatal lnmindev lndyadictrade lngdplow lngdphigh low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev lndyadictrade lngdplow lngdphigh low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

*Trade openness*
logit midfatal lnmindev openness_low low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev openness_low low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

logit midfatal lnmindev openness_low low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev openness_low low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

*Trade agreements*
logit midfatal lnmindev PTASameGT0_lag low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev PTASameGT0_lag low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

logit midfatal lnmindev GATT_lag low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog
logit midfatal lower_conc lnmindev GATT_lag low_share low_dem high_dem contig_dummy allies lncaprat lndist majpow  numstate pcy pcy2 pcy3, robust cluster(dyadid) nolog

drop  pcy pcy2 pcy3


****************************************************************************

*****Results for Table 3*****
* COPDAB data analysis (1948-78) (TABLE 3)
* Negative binomial on conflict event count per year
* Note: Conflictsum=annual sum of conflictual events directed by state against target
* Note: Unit of analysis is the directed-dyad year

use "(...)KleinbergRobinsonFrench2012JOP_COPDAB.dta"
nbreg conflict lngdppc_a lngdppc_b tshare_ba tconc_a tshare_ab tconc_b dem_a dem_b dem_dyad majpow capshare lndist contig_dummy numstate allies, robust cluster(dyadid) nolog

***Robustness checks***
*poltically relevant dyads only*
nbreg conflict tshare_ba tconc_a tshare_ab tconc_b dem_a dem_b dem_dyad majpow  capshare lndist contig_dummy numstate allies if politrel==1, robust cluster(dyadid) nolog
*trade openness as alternative measure of trade dependence*
nbreg conflict openness_a openness_b tconc_a tconc_b dem_a dem_b dem_dyad majpow  capshare lndist contig_dummy numstate allies, robust cluster(dyadid) nolog
*joint membership in preferential trade agreements*
nbreg conflict PTASameGT0_lag tshare_ba tconc_a tshare_ab tconc_b dem_a dem_b dem_dyad majpow  capshare lndist contig_dummy numstate allies, robust cluster(dyadid) nolog
*policy similarity score as alternative measure of political relations*
nbreg conflict tshare_ba tconc_a tshare_ab tconc_b dem_a dem_b dem_dyad majpow  capshare lndist contig_dummy numstate s_wt_glo, robust cluster(dyadid) nolog

******************************************************************************************************
***END OF REPLICATION***
